---
name: Proposal
about: Propose a change to the project. This covers changes to docs, file organization or CI/CD.

---

**Problem Statement**
Describe the problem you are facing with the project.

**Describe the Proposal**
Describe the change you would like to see in the project.

**Steps to Implement Proposal**
List steps required to implement the change you would like to see.
